@@ -1,10 +1,10 @@
-use 5.020;
+use 5.24.1; # Dunno how to make tests pass for v5.22.1 to v5.24.0 so this is how it is
 use strict;
 use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.17_12';
+  our $VERSION = '0.17_13';
 
   use Zydeco
     authority => 'cpan:SMONFF',
